@@ -62,11 +62,40 @@ void XML::saveProgram(QString name, QModelIndexList exercises)
     QDomDocument doc( "Program" );
     QString str = "/home/user/.qexercise";
     QFile file( str + "/program.xml" );
-    file.open( QIODevice::ReadOnly );
+    file.open( QIODevice::ReadWrite );
     doc.setContent( &file );
 
+    file.close();
 
+
+    //leta efter ett program med samma namn, isf ta bort den
     QDomElement root = doc.documentElement();
+
+
+    QDomNode n = root.firstChild();
+    while( !n.isNull() )
+    {
+      QDomElement e = n.toElement();
+      if( !e.isNull() )
+      {
+        if( e.tagName() == "programs" )
+        {
+            if(name == e.attribute( "name", "" ))
+            {
+                removeElement(name);
+            }
+        }
+      }
+      n = n.nextSibling();
+   }
+   QTextStream ts( &file );
+   ts << doc.toString();
+
+   doc.clear();
+   file.open( QIODevice::ReadWrite );
+   doc.setContent( &file );
+   file.remove();
+   root = doc.documentElement();
     if( root.tagName() != "programs" )
     {
         root = doc.createElement( "programs" );
@@ -79,8 +108,8 @@ void XML::saveProgram(QString name, QModelIndexList exercises)
     if(!file.open(QIODevice::WriteOnly))
         return ;
 
-    QTextStream ts( &file );
-    ts << doc.toString();
+    QTextStream ts2( &file );
+    ts2 << doc.toString();
 
     file.close();
 
@@ -540,7 +569,6 @@ QList< QList<QString> > XML::readHistory()
 void XML::import(QString filename)
 {
     QString name, group, muscle, info;
-
     QDomDocument doc( "Exercises" );
     QFile file(filename);
     file.open( QIODevice::ReadOnly );
@@ -555,7 +583,13 @@ void XML::import(QString filename)
       QDomElement e = n.toElement();
       if( !e.isNull() )
       {
-        if( e.tagName() == "exercise" )
+          if( e.tagName() == "exercise" && e.attribute( "group", "" ) == "Cardio")
+          {
+
+              name = e.attribute( "name", "" );
+              saveCardio(name);
+          }
+        else if( e.tagName() == "exercise" )
         {
 
             name = e.attribute( "name", "" );
@@ -612,7 +646,7 @@ void XML::saveEx(QString name, QString group, QString muscle,
     doc.setContent( &file );
 
     file.close();
-
+    qDebug () << "xml::saveEx 1";
     //leta efter en vning med samma namn, isf ta bort den
     QDomElement root = doc.documentElement();
 
@@ -627,6 +661,7 @@ void XML::saveEx(QString name, QString group, QString muscle,
             if(name == e.attribute( "name", "" ))
             {
                 removeElement(name);
+                qDebug () << "xml::saveEx 2";
             }
         }
       }
@@ -647,13 +682,15 @@ void XML::saveEx(QString name, QString group, QString muscle,
        doc.appendChild( root );
    }
    file.close();
-
+    qDebug () << "xml::saveEx 3";
    root.appendChild(createExerciseNode(doc, name, group, muscle, info));
 
    if(!file.open(QIODevice::WriteOnly))
        return;
-   ts << doc.toString();
 
+   QTextStream ts2( &file );
+   ts2 << doc.toString();
+    qDebug () << "xml::saveEx 4";
    file.close();
    return;
 }
@@ -664,7 +701,7 @@ void XML::saveCardio(QString name)
     QDomDocument doc( "Exercises" );
     QString str = "/home/user/.qexercise";
     QFile file( str + "/cardio.xml" );
-    file.open( QIODevice::ReadOnly );
+    file.open( QIODevice::ReadWrite );
     doc.setContent( &file );
 
     file.close();
@@ -694,7 +731,7 @@ void XML::saveCardio(QString name)
    ts << doc.toString();
 
    doc.clear();
-   file.open( QIODevice::ReadOnly );
+   file.open( QIODevice::ReadWrite );
    doc.setContent( &file );
    file.remove();
    root = doc.documentElement();
@@ -710,7 +747,8 @@ void XML::saveCardio(QString name)
    if(!file.open(QIODevice::WriteOnly))
        return;
 
-   ts << doc.toString();
+   QTextStream ts2( &file );
+   ts2 << doc.toString();
 
    file.close();
    return;
@@ -984,6 +1022,7 @@ QDomElement XML::createExerciseNode( QDomDocument &d, QString name, QString grou
    cn.setAttribute( "muscle", muscle );
    cn.setAttribute( "info", info );
 
+   qDebug () << "xml::createExerciseNode";
    return cn;
 }
 
@@ -992,7 +1031,7 @@ QDomElement XML::createCardioNode( QDomDocument &d, QString name)
    QDomElement cn = d.createElement( "exercise" );
 
    cn.setAttribute( "name", name );
-   //cn.setAttribute( "group", group);
+   cn.setAttribute( "group", "Cardio");
    cn.setAttribute( "distance", "0" );
    cn.setAttribute( "min", "0" );
    cn.setAttribute( "sec", "0" );
